@@ -71,40 +71,44 @@ class Q_WAYLAND_CLIENT_EXPORT QWaylandIntegration : public QPlatformIntegration
 {
 public:
     QWaylandIntegration();
-    ~QWaylandIntegration();
+    ~QWaylandIntegration() override;
 
-    bool hasCapability(QPlatformIntegration::Capability cap) const Q_DECL_OVERRIDE;
-    QPlatformWindow *createPlatformWindow(QWindow *window) const Q_DECL_OVERRIDE;
+    bool hasFailed() { return mFailed; }
+
+    bool hasCapability(QPlatformIntegration::Capability cap) const override;
+    QPlatformWindow *createPlatformWindow(QWindow *window) const override;
 #if QT_CONFIG(opengl)
-    QPlatformOpenGLContext *createPlatformOpenGLContext(QOpenGLContext *context) const Q_DECL_OVERRIDE;
+    QPlatformOpenGLContext *createPlatformOpenGLContext(QOpenGLContext *context) const override;
 #endif
-    QPlatformBackingStore *createPlatformBackingStore(QWindow *window) const Q_DECL_OVERRIDE;
+    QPlatformBackingStore *createPlatformBackingStore(QWindow *window) const override;
 
-    QAbstractEventDispatcher *createEventDispatcher() const Q_DECL_OVERRIDE;
-    void initialize() Q_DECL_OVERRIDE;
+    QAbstractEventDispatcher *createEventDispatcher() const override;
+    void initialize() override;
 
-    QPlatformFontDatabase *fontDatabase() const Q_DECL_OVERRIDE;
+    QPlatformFontDatabase *fontDatabase() const override;
 
-    QPlatformNativeInterface *nativeInterface() const Q_DECL_OVERRIDE;
+    QPlatformNativeInterface *nativeInterface() const override;
+#if QT_CONFIG(clipboard)
+    QPlatformClipboard *clipboard() const override;
+#endif
 #if QT_CONFIG(draganddrop)
-    QPlatformClipboard *clipboard() const Q_DECL_OVERRIDE;
-    QPlatformDrag *drag() const Q_DECL_OVERRIDE;
+    QPlatformDrag *drag() const override;
 #endif
-    QPlatformInputContext *inputContext() const Q_DECL_OVERRIDE;
+    QPlatformInputContext *inputContext() const override;
 
-    QVariant styleHint(StyleHint hint) const Q_DECL_OVERRIDE;
+    QVariant styleHint(StyleHint hint) const override;
 
 #if QT_CONFIG(accessibility)
-    QPlatformAccessibility *accessibility() const Q_DECL_OVERRIDE;
+    QPlatformAccessibility *accessibility() const override;
 #endif
 
-    QPlatformServices *services() const Q_DECL_OVERRIDE;
+    QPlatformServices *services() const override;
 
     QWaylandDisplay *display() const;
 
-    QStringList themeNames() const Q_DECL_OVERRIDE;
+    QStringList themeNames() const override;
 
-    QPlatformTheme *createPlatformTheme(const QString &name) const Q_DECL_OVERRIDE;
+    QPlatformTheme *createPlatformTheme(const QString &name) const override;
 
     QWaylandInputDevice *createInputDevice(QWaylandDisplay *display, int version, uint32_t id);
 
@@ -113,7 +117,8 @@ public:
     virtual QWaylandShellIntegration *shellIntegration() const;
 
 private:
-    // NOTE: mDisplay *must* be destructed after mDrag and mClientBufferIntegration.
+    // NOTE: mDisplay *must* be destructed after mDrag and mClientBufferIntegration
+    // and mShellIntegration.
     // Do not move this definition into the private section at the bottom.
     QScopedPointer<QWaylandDisplay> mDisplay;
 
@@ -131,8 +136,10 @@ private:
     QWaylandShellIntegration *createShellIntegration(const QString& interfaceName);
 
     QScopedPointer<QPlatformFontDatabase> mFontDb;
-#if QT_CONFIG(draganddrop)
+#if QT_CONFIG(clipboard)
     QScopedPointer<QPlatformClipboard> mClipboard;
+#endif
+#if QT_CONFIG(draganddrop)
     QScopedPointer<QPlatformDrag> mDrag;
 #endif
     QScopedPointer<QPlatformNativeInterface> mNativeInterface;
@@ -140,9 +147,10 @@ private:
 #if QT_CONFIG(accessibility)
     QScopedPointer<QPlatformAccessibility> mAccessibility;
 #endif
-    bool mClientBufferIntegrationInitialized;
-    bool mServerBufferIntegrationInitialized;
-    bool mShellIntegrationInitialized;
+    bool mFailed = false;
+    bool mClientBufferIntegrationInitialized = false;
+    bool mServerBufferIntegrationInitialized = false;
+    bool mShellIntegrationInitialized = false;
 
     friend class QWaylandDisplay;
 };
