@@ -17,6 +17,7 @@
 QT_BEGIN_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
+QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")
 
 #if !defined(Q_WAYLAND_SERVER_TOUCH_EXTENSION_EXPORT)
 #  if defined(QT_SHARED)
@@ -46,7 +47,7 @@ namespace QtWaylandServer {
             qt_touch_extension *touch_extension_object;
             struct ::wl_resource *handle;
 
-            struct ::wl_client *client() const { return handle->client; }
+            struct ::wl_client *client() const { return wl_resource_get_client(handle); }
             int version() const { return wl_resource_get_version(handle); }
 
             static Resource *fromResource(struct ::wl_resource *resource);
